@@ -154,6 +154,22 @@ class RenaultSession:
                 self._credentials[gigya.GIGYA_JWT] = JWTCredential(jwt)
                 return jwt
 
+    async def http_request(
+        self, method: str, endpoint: str, json: Optional[Dict[str, Any]] = None
+    ) -> models.KamereonResponse:
+        """GET to specified endpoint."""
+        url = (await self._get_kamereon_root_url()) + endpoint
+        params = {"country": await self._get_country()}
+        return await kamereon.request(
+            websession=self._websession,
+            method=method,
+            url=url,
+            api_key=await self._get_kamereon_api_key(),
+            gigya_jwt=await self._get_jwt(),
+            params=params,
+            json=json,
+        )
+
     async def get_person(self) -> models.KamereonPersonResponse:
         """GET to /persons/{person_id}."""
         return await kamereon.get_person(
@@ -178,6 +194,20 @@ class RenaultSession:
             account_id=account_id,
         )
 
+    async def get_vehicle_details(
+        self, account_id: str, vin: str
+    ) -> models.KamereonVehicleDetailsResponse:
+        """GET to /accounts/{account_id}/vehicles/{vin}/details."""
+        return await kamereon.get_vehicle_details(
+            websession=self._websession,
+            root_url=await self._get_kamereon_root_url(),
+            api_key=await self._get_kamereon_api_key(),
+            gigya_jwt=await self._get_jwt(),
+            country=await self._get_country(),
+            account_id=account_id,
+            vin=vin,
+        )
+
     async def get_vehicle_data(
         self,
         account_id: str,
@@ -198,6 +228,23 @@ class RenaultSession:
             params=params,
         )
 
+    async def get_vehicle_contracts(
+        self,
+        account_id: str,
+        vin: str,
+    ) -> models.KamereonVehicleContractsResponse:
+        """GET to /v{endpoint_version}/cars/{vin}/contracts."""
+        return await kamereon.get_vehicle_contracts(
+            websession=self._websession,
+            root_url=await self._get_kamereon_root_url(),
+            api_key=await self._get_kamereon_api_key(),
+            gigya_jwt=await self._get_jwt(),
+            country=await self._get_country(),
+            account_id=account_id,
+            vin=vin,
+            locale=await self._get_credential(CONF_LOCALE),
+        )
+
     async def set_vehicle_action(
         self,
         account_id: str,
